﻿using System.Diagnostics;
using Microsoft.AspNetCore.Identity;
using Microsoft.AspNetCore.Mvc;
using Sequence.Entities;
using Sequence.Models;

namespace Sequence.Controllers;

public class HomeController : Controller
{
    private readonly ILogger<HomeController> _logger;
    private readonly DbContext dbContext;

    public HomeController(ILogger<HomeController> logger, DbContext dbContext)
    {
        _logger = logger;
        this.dbContext = dbContext;
    }

    public IActionResult Index()
    {
        return View();
    }

    public async Task<IActionResult> CreateMatch([FromServices] UserManager<User> userManager)
    {
        var userOne = new User
        {
            Name = "Krystle",
            UserName = "krystle",
            Email = "krystle@allwillynilly.com"
        };

        var userTwo = new User
        {
            Name = "Ryan",
            UserName = "ryan",
            Email = "ryan@binarydad.com"
        };

        var resultKrystle = await userManager.CreateAsync(userOne, "C0urtY@rd");
        var resultRyan = await userManager.CreateAsync(userTwo, "C0urtY@rd");

        var playerOne = new Player
        {
            Id = Guid.NewGuid(),
            Alias = "SwiggitySwooty",
            UserId = resultKrystle
        };

        var playerTwo = new Player
        {
            Id = Guid.NewGuid(),
            Alias = "BabeFoy",
            UserId = Guid.Parse("08db3712-7c5f-430b-882e-44abd63b5324")
        };

        var players = new[] { playerOne, playerTwo };

        var match = new Match
        {
            Id = Guid.NewGuid(),
            Created = DateTime.Now,
            CurrentTurnPlayerId = playerOne.Id,
            PlayerOneId = playerOne.Id,
            PlayerTwoId = playerTwo.Id
        };

        var deck = cards
            .OrderBy(c => Guid.NewGuid())
            .Select(c => new DeckCard
            {
                CardId = c.Id,
                MatchId = match.Id,
                Id = Guid.NewGuid()
            })
            .ToList();

        var handCards = new List<HandCard>();

        for (var i = 1; i <= 14; i += 2)
        {
            var deckCard = deck[i];
            var deckCard2 = deck[i + 1];

            deck.Remove(deckCard);

            handCards.Add(new HandCard
            {
                DeckCardId = deckCard.Id,
                PlayerId = playerOne.Id,
                Id = Guid.NewGuid()
            });

            deck.Remove(deckCard2);

            handCards.Add(new HandCard
            {
                DeckCardId = deckCard2.Id,
                PlayerId = playerTwo.Id,
                Id = Guid.NewGuid()
            });
        }
    }

    [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
    public IActionResult Error()
    {
        return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
    }
}
